==> haskell-quickcheck-instances-0.3.30-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-instances
version:              0.3.30
visibility:           public
id:                   quickcheck-instances-0.3.30-EK0iWhsUE5mJ32H5j3sYlV
key:                  quickcheck-instances-0.3.30-EK0iWhsUE5mJ32H5j3sYlV
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  d44b99f0c603905619ba7d074cd10568
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-instances-0.3.30
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-instances-0.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.30-EK0iWhsUE5mJ32H5j3sYlV
depends:
    OneTuple-0.4.1.1-40NyffdgEi5Dyrbz0MGlFv
    QuickCheck-2.14.3-4RnDMHKDhpPJEbozrkRwOm array-0.5.4.0
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-EnSgvsXdRX78Hz3HwummHY containers-0.6.5.1
    data-array-byte-0.1.0.1-3GdB6U3lWZEI2cJx8RfqhQ
    data-fix-0.3.2-K0KIwzjGlWj3FE6rKu1fg6
    hashable-1.4.4.0-EsPTAmPpYqX3hovcHlHOLX
    integer-logarithms-1.0.3.1-6P0sCe8RoauAWF13sn9GHc
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg
    primitive-0.7.4.0-6KmKRdtjMquLpK2leC8DMp
    scientific-0.3.7.0-1j3FKEOO1AWBjqM65TX7Sj
    splitmix-0.1.0.5-HoSTeY0pgNNC2z5u42aXtd
    strict-0.5-1JwcfvUpjof68c0VbQ4NnS
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP text-1.2.5.0
    text-short-0.1.6-4T40OIThTMkBqQ08Uui5nY
    these-1.2-Ilt9y7CMLaX5099VwZr2Ed time-1.11.1.1
    time-compat-1.9.6.1-B3BnoEMkUVPvereBtkXcD transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-3olzmtJszxXc2LJr1lW5F
    uuid-types-1.0.6-J0DTbmmPJ4NExOxtFmVr8X
    vector-0.13.1.0-IOwb1qSGKSdHIyg7Qp7MNu

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.30-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-instances
version:              0.3.30
visibility:           public
id:                   quickcheck-instances-0.3.30-GvC5Ynwq5U06sb3ziT3Qoa
key:                  quickcheck-instances-0.3.30-GvC5Ynwq5U06sb3ziT3Qoa
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  f27beb9fb770dc183f40e27d41b61eac
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-instances-0.3.30
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-instances-0.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.30-GvC5Ynwq5U06sb3ziT3Qoa
depends:
    OneTuple-0.4.1.1-40NyffdgEi5Dyrbz0MGlFv
    QuickCheck-2.14.3-4RnDMHKDhpPJEbozrkRwOm array-0.5.4.0
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-EnSgvsXdRX78Hz3HwummHY containers-0.6.5.1
    data-array-byte-0.1.0.1-3GdB6U3lWZEI2cJx8RfqhQ
    data-fix-0.3.2-K0KIwzjGlWj3FE6rKu1fg6
    hashable-1.4.4.0-EsPTAmPpYqX3hovcHlHOLX
    integer-logarithms-1.0.3.1-6P0sCe8RoauAWF13sn9GHc
    old-time-1.1.0.4-Dlc8YwGlkPi2Y3VNXkrOFg
    primitive-0.7.4.0-6KmKRdtjMquLpK2leC8DMp
    scientific-0.3.7.0-1j3FKEOO1AWBjqM65TX7Sj
    splitmix-0.1.0.5-HoSTeY0pgNNC2z5u42aXtd
    strict-0.5-I1QlvpN8R7x80TzoNfS6Q7
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP text-1.2.5.0
    text-short-0.1.6-4T40OIThTMkBqQ08Uui5nY
    these-1.2-JSDM0V4jeC67wQ6jFiVXg time-1.11.1.1
    time-compat-1.9.6.1-B3BnoEMkUVPvereBtkXcD transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-3olzmtJszxXc2LJr1lW5F
    uuid-types-1.0.6-J0DTbmmPJ4NExOxtFmVr8X
    vector-0.13.1.0-IOwb1qSGKSdHIyg7Qp7MNu

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
